@@ -1,5 +1,5 @@
 <?php
-/* $Id: bulgarian-koi8-r.inc.php,v 2.69.2.1 2005/04/10 12:08:06 lem9 Exp $ */
+/* $Id: bulgarian-koi8-r.inc.php,v 2.79 2005/08/18 10:09:13 lem9 Exp $ */
 
 /**
  * Translated by Stanislav Yordanov <stanprog at stanprog.com>
@@ -23,17 +23,18 @@ $datefmt = '%e %B %Y  %H:%M';
 
 $timespanfmt = '%s , %s , %s   %s ';
 
-$strAPrimaryKey = 'ee     ';
 $strAbortedClients = '';
 $strAbsolutePathToDocSqlDir = '        docSQL ';
-$strAccessDenied = ' ';
 $strAccessDeniedExplanation = 'phpMyAdmin       MySQL ,    .    ,      config.inc.php     ,          MySQL .';
+$strAccessDenied = ' ';
 $strAction = '';
 $strAddAutoIncrement = '  AUTO_INCREMENT';
 $strAddConstraints = '  ';
 $strAddDeleteColumn = '/   ';
 $strAddDeleteRow = '/   ';
 $strAddDropDatabase = '  DROP DATABASE';
+$strAddedColumnComment = '   ';
+$strAddedColumnRelation = '   ';
 $strAddFields = '   %s ()';
 $strAddHeaderComment = '     (\\n  )';
 $strAddIfNotExists = '  IF NOT EXISTS'; 
@@ -43,26 +44,26 @@ $strAddPrivilegesOnDb = '       ';
 $strAddPrivilegesOnTbl = '     ';
 $strAddSearchConditions = '    (  "where" ):';
 $strAddToIndex = ' &nbsp;%s&nbsp;() ()   ';
-$strAddUser = '   .';
 $strAddUserMessage = '   .';
-$strAddedColumnComment = '   ';
-$strAddedColumnRelation = '   ';
+$strAddUser = '   .';
 $strAdministration = '';
 $strAffectedRows = ' :';
-$strAfter = ' %s';
 $strAfterInsertBack = ' ';
 $strAfterInsertNewInsert = '   ';
 $strAfterInsertNext = '   ';
 $strAfterInsertSame = '   ';
+$strAfter = ' %s';
 $strAll = '';
 $strAllTableSameWidth = '        ?';
 $strAlterOrderBy = '   ';
-$strAnIndex = '    %s';
 $strAnalyzeTable = '  ';
 $strAnd = '';
+$strAnIndex = '    %s';
 $strAny = '';
 $strAnyHost = ' ';
 $strAnyUser = ' ';
+$strApproximateCount = '    .  FAQ 3.11';
+$strAPrimaryKey = 'ee     ';
 $strArabic = '';
 $strArmenian = '';
 $strAscending = '';
@@ -85,13 +86,12 @@ $strBookmarkOptions = 'Bookmark ';
 $strBookmarkQuery = '  SQL ';
 $strBookmarkThis = '  SQL ';
 $strBookmarkView = ' ';
-$strBrowse = '';
 $strBrowseForeignValues = '  (foreign) ';
+$strBrowse = '';
 $strBulgarian = '';
 $strBzError = 'phpMyAdmin     (dump)    Bz2      PHP.        <code>$cfg[\'BZipDump\']</code>       phpMyAdmin  <code>FALSE</code>.        Bz2 ,      -   PHP.   %s   .';
 $strBzip = '"bzip-"';
 
-$strCSVOptions = 'CSV ';
 $strCalendar = ''; 
 $strCannotLogin = '      MySQL ';
 $strCantLoad = '     %s,<br />    PHP';
@@ -103,22 +103,22 @@ $strCarriage = '    : \\r';
 $strCaseInsensitive = '  ';
 $strCaseSensitive = '  ';
 $strCentralEuropean = ' ';
-$strChange = '';
-$strChangeCopyMode = '       ...';
 $strChangeCopyModeCopy = '...   .';
 $strChangeCopyModeDeleteAndReload = ' ...             .';
 $strChangeCopyModeJustDelete = ' ...       .';
+$strChangeCopyMode = '       ...';
 $strChangeCopyModeRevoke = ' ...           .';
 $strChangeCopyUser = '    /   ';
 $strChangeDisplay = '   ';
+$strChange = '';
 $strChangePassword = '  ';
-$strCharset = '  ';
 $strCharsetOfFile = '    :';
-$strCharsets = '  ';
 $strCharsetsAndCollations = '    ';
+$strCharsets = '  ';
+$strCharset = '  ';
 $strCheckAll = '  ';
-$strCheckPrivs = '  ';
 $strCheckPrivsLong = '      &quot;%s&quot;.';
+$strCheckPrivs = '  ';
 $strCheckTable = '  ';
 $strChoosePage = '    ';
 $strColComFeat = '    ';
@@ -126,8 +126,9 @@ $strCollation = '';
 $strColumnNames = '  ';
 $strColumnPrivileges = '   ';
 $strCommand = '';
-$strComments = '';
 $strCommentsForTable = '  ';
+$strComments = '';
+$strCompatibleHashing = 'MySQL&nbsp;4.0 ';
 $strCompleteInserts = ' INSERT-';
 $strCompression = '';
 $strConfigFileError = 'phpMyAdmin       !<br />      PHP           .<br />        -       PHP .  -   ,       .<br />    ,   .';
@@ -137,27 +138,43 @@ $strConnections = '';
 $strConstraintsForDumped = '   ';
 $strConstraintsForTable = '  ';
 $strCookiesRequired = '    "Cookies".';
-$strCopyTable = '   (  <b>.</b>):';
 $strCopyTableOK = ' %s    %s.';
 $strCopyTableSameNames = '        !';
+$strCopyTable = '   (  <b>.</b>):';
 $strCouldNotKill = 'phpMyAdmin      %s.     .';
-$strCreate = '';
 $strCreateIndex = '    &nbsp;%s&nbsp;';
 $strCreateIndexTopic = '  ';
 $strCreateNewDatabase = '   ';
 $strCreateNewTable = '     %s';
+$strCreate = '';
 $strCreatePage = '  ';
 $strCreatePdfFeat = '  PDF-';
 $strCreationDates = '//  ';
 $strCriteria = '';
 $strCroatian = '';
+$strCSVOptions = 'CSV ';
 $strCyrillic = '';
 $strCzech = '';
 $strCzechSlovak = '';
 
+$strDanish = '';
+$strDatabase = '';
+$strDatabaseEmpty = '      !';
+$strDatabaseExportOptions = '      ';
+$strDatabaseHasBeenDropped = '  %s  .';
+$strDatabaseNoTable = '    !';
+$strDatabasesDropped = '%s      .';
+$strDatabasesStatsDisable = ' ';
+$strDatabasesStatsEnable = ' ';
+$strDatabasesStatsHeavyTraffic = ':                  MySQL .';
+$strDatabasesStats = '    ';
+$strDatabases = '  ';
+$strDataDict = '  ';
+$strData = '';
+$strDataOnly = ' ';
 $strDBComment = '    : ';
-$strDBGContext = '';
 $strDBGContextID = ' ID';
+$strDBGContext = '';
 $strDBGHits = '';
 $strDBGLine = '';
 $strDBGMaxTimeMs = '. , ms';
@@ -165,54 +182,39 @@ $strDBGMinTimeMs = '. , ms';
 $strDBGModule = '';
 $strDBGTimePerHitMs = '/, ms';
 $strDBGTotalTimeMs = ' , ms';
-$strDBRename = '     '; 
-$strDanish = '';
-$strData = '';
-$strDataDict = '  ';
-$strDataOnly = ' ';
-$strDatabase = '';
-$strDatabaseEmpty = '      !';
-$strDatabaseExportOptions = '      ';
-$strDatabaseHasBeenDropped = '  %s  .';
-$strDatabaseNoTable = '    !';
-$strDatabases = '  ';
-$strDatabasesDropped = '%s      .';
-$strDatabasesStats = '    ';
-$strDatabasesStatsDisable = ' ';
-$strDatabasesStatsEnable = ' ';
-$strDatabasesStatsHeavyTraffic = ':                  MySQL .';
 $strDbPrivileges = '     ';
+$strDBRename = '     '; 
 $strDbSpecific = '    ';
-$strDefault = ' ';
 $strDefaultEngine = '%s         MySQL .';
 $strDefaultValueHelp = '   ,     ,     ,   : a';
+$strDefault = ' ';
 $strDefragment = '  ';
-$strDelOld = '         .      ?';
 $strDelayedInserts = '   ';
-$strDelete = '';
-$strDeleteAndFlush = '        .';
 $strDeleteAndFlushDescr = '  - ,         .';
+$strDeleteAndFlush = '        .';
 $strDeleted = '  ';
 $strDeletedRows = ' :';
+$strDelete = '';
 $strDeleting = '  %s';
+$strDelOld = '         .      ?';
 $strDescending = '';
 $strDescription = '';
 $strDictionary = '';
-$strDisableForeignChecks = '     ';
 $strDisabled = '';
+$strDisableForeignChecks = '     ';
 $strDisplayFeat = ' ';
 $strDisplayOrder = ' :';
 $strDisplayPDF = ' PDF ';
 $strDoAQuery = ' "  " (   : "%")';
-$strDoYouReally = '     ';
 $strDocu = '';
-$strDrop = '';
+$strDoYouReally = '     ';
 $strDropDatabaseStrongWarning = '      !';
+$strDrop = '';
 $strDropSelectedDatabases = '     ';
 $strDropUsersDb = '           .';
+$strDumpingData = ' ()    ';
 $strDumpSaved = '()     %s.';
 $strDumpXRows = '- %s     %s.';
-$strDumpingData = ' ()    ';
 $strDynamic = '';
 
 $strEdit = '';
@@ -223,13 +225,13 @@ $strEmpty = '';
 $strEmptyResultSet = 'MySQL    (..  ).';
 $strEnabled = '';
 $strEncloseInTransaction = '    ';
-$strEnd = '';
 $strEndCut = 'END CUT';
+$strEnd = '';
 $strEndRaw = 'END RAW';
 $strEngineAvailable = '%s     MySQL .';
 $strEngineDisabled = '%s     MySQL .';
-$strEngineUnsupported = ' MySQL       %s.';
 $strEngines = '';
+$strEngineUnsupported = ' MySQL       %s.';
 $strEnglish = '';
 $strEnglishPrivileges = ' :     MySQL    . ';
 $strError = '';
@@ -243,29 +245,29 @@ $strExtendedInserts = ' INSERT-';
 $strExtra = '';
 
 $strFailedAttempts = '  ';
-$strField = '';
 $strFieldHasBeenDropped = ' %s  ';
-$strFields = '';
 $strFieldsEmpty = '     ! ';
 $strFieldsEnclosedBy = '   ';
 $strFieldsEscapedBy = '   ';
 $strFieldsTerminatedBy = '  ';
+$strFields = '';
+$strField = '';
 $strFileAlreadyExists = ' %s    ,         .';
 $strFileCouldNotBeRead = '     ';
-$strFileNameTemplate = '   ';
 $strFileNameTemplateHelp = ' __DB__      , __TABLE__        %sstrftime%s      ,      .      .';
 $strFileNameTemplateRemember = '  ';
+$strFileNameTemplate = '   ';
 $strFixed = '';
 $strFlushPrivilegesNote = ': phpMyAdmin          MySQL.                     .   ,   %s %s   .';
-$strFlushTable = '    ("FLUSH")';
-$strFormEmpty = '     !';
+$strFlushTable = '     ("FLUSH")';
 $strFormat = '';
+$strFormEmpty = '     !';
 $strFullText = ' ';
 $strFunction = '';
 
 $strGenBy = ' ';
-$strGenTime = '  ';
 $strGeneralRelationFeat = '   ';
+$strGenTime = '  ';
 $strGeorgian = '';
 $strGerman = '';
 $strGlobal = '';
@@ -280,10 +282,11 @@ $strHasBeenAltered = ' .';
 $strHasBeenCreated = ' .';
 $strHaveToShow = '       ';
 $strHebrew = '';
+$strHexForBinary = '      ';
 $strHome = '';
 $strHomepageOfficial = '    phpMyAdmin ';
-$strHost = '';
 $strHostEmpty = '    !';
+$strHost = '';
 $strHungarian = '';
 
 $strIcelandic = '';
@@ -291,47 +294,52 @@ $strId = 'ID';
 $strIdxFulltext = '';
 $strIfYouWish = '        ,       .';
 $strIgnore = '';
+$strIgnoreInserts = '  INSERT IGNORE';
 $strIgnoringFile = '   %s';
 $strImportDocSQL = ' docSQL ';
 $strImportFiles = '  ';
 $strImportFinished = ' ';
-$strInUse = '';
-$strIndex = '';
+$strIndexes = '';
 $strIndexHasBeenDropped = ' %s  ';
 $strIndexName = '  &nbsp;:';
+$strIndex = '';
 $strIndexType = '  &nbsp;:';
-$strIndexes = '';
 $strInnodbStat = 'InnoDB ';
 $strInsecureMySQL = '     (root  ),       MySQL  .  MySQL             . T      .';
-$strInsert = '';
 $strInsertAsNewRow = '   ';
-$strInsertNewRow = '   ';
-$strInsertTextfiles = '     ';
 $strInsertedRowId = ' ID  :';
 $strInsertedRows = ' :';
+$strInsertNewRow = '   ';
+$strInsert = '';
+$strInsertTextfiles = '     ';
 $strInstructions = '';
 $strInternalNotNecessary = '*          InnoDB.';
 $strInternalRelations = ' ';
+$strInUse = '';
+$strInvalidColumnCount = '      -  .';
+$strInvalidFieldAddCount = '     .';
+$strInvalidFieldCount = '      .';
+$strInvalidRowNumber = '%d      .';
 
 $strJapanese = '';
 $strJumpToDB = '     &quot;%s&quot;.';
-$strJustDelete = '      .';
 $strJustDeleteDescr = '&quot;&quot;        ,     .';
+$strJustDelete = '      .';
 
 $strKeepPass = '    ';
 $strKeyname = '  ';
 $strKill = '';
 $strKorean = '';
 
-$strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX ';
 $strLandscape = '';
 $strLatexCaption = '  ';
 $strLatexContent = '   __TABLE__';
-$strLatexContinued = '()';
 $strLatexContinuedCaption = '    ';
+$strLatexContinued = '()';
 $strLatexIncludeCaption = '    ';
 $strLatexLabel = '  ';
+$strLaTeX = 'LaTeX';
+$strLaTeXOptions = 'LaTeX ';
 $strLatexStructure = '   __TABLE__';
 $strLatvian = '';
 $strLengthSet = '/*';
@@ -345,34 +353,35 @@ $strLoadExplanation = '     ,         .';
 $strLoadMethod = 'LOAD ';
 $strLocalhost = '';
 $strLocationTextfile = '   ';
+$strLoginInformation = '  ';
+$strLogin = '';
+$strLogout = '  ';
 $strLogPassword = ':';
 $strLogServer = '';
 $strLogUsername = ':';
-$strLogin = '';
-$strLoginInformation = '  ';
-$strLogout = '  ';
 
-$strMIMETypesForTable = 'MIME   ';
-$strMIME_MIMEtype = 'MIME-';
+$strMaximumSize = ' : %s%s';
 $strMIME_available_mime = ' MIME-';
 $strMIME_available_transform = ' ';
 $strMIME_description = '';
+$strMIME_MIMEtype = 'MIME-';
 $strMIME_nodescription = '    .<br />         %s.';
 $strMIME_transformation = ' ';
 $strMIME_transformation_note = '         MIME-type    %s  %s';
-$strMIME_transformation_options = '  ';
 $strMIME_transformation_options_note = '          : \'a\',\'b\',\'c\'...<br />       ("\")    ("\'")   ,        ( \'\\\\xyz\'  \'a\\\'b\').';
+$strMIME_transformation_options = '  ';
+$strMIMETypesForTable = 'MIME   ';
 $strMIME_without = 'MIME-types          ';
-$strMaximumSize = ' : %s%s';
 $strModifications = '  ';
-$strModify = '';
 $strModifyIndexTopic = '  ';
+$strModify = '';
 $strMoreStatusVars = '   ';
 $strMoveTable = '    (  <b>.</b>):';
 $strMoveTableOK = ' %s    %s.';
 $strMoveTableSameNames = '        !';
 $strMultilingual = '';
 $strMustSelectFile = '     .';
+$strMyISAMMaxExtraSortFileSize = '        ';
 $strMyISAMRecoverOptions = '   ';
 $strMyISAMSortBufferSize = '    ';
 $strMySQLCharset = '    MySQL';
@@ -387,7 +396,6 @@ $strMySQLShowVars = '   MySQL';
 $strName = '';
 $strNeedPrimaryKey = '    (primary key)   .';
 $strNext = '';
-$strNo = '';
 $strNoDatabases = '   ';
 $strNoDatabasesSelected = '    .';
 $strNoDescription = ' ';
@@ -395,9 +403,11 @@ $strNoDetailsForEngine = '         .';
 $strNoDropDatabases = '"DROP DATABASE"   .';
 $strNoExplain = ' Explain SQL';
 $strNoFrames = 'phpMyAdmin      ,   <b>frames</b>.';
-$strNoIndex = '   !';
 $strNoIndexPartsDefined = '     !';
+$strNoIndex = '   !';
 $strNoModification = ' ';
+$strNone = '';
+$strNo = '';
 $strNoOptions = '   ';
 $strNoPassword = ' ';
 $strNoPermission = '        %s.';
@@ -408,20 +418,18 @@ $strNoRights = '           !';
 $strNoRowsSelected = '  ';
 $strNoSpace = '       %s.';
 $strNoTablesFound = '     .';
-$strNoUsersFound = ' ().';
-$strNoValidateSQL = ' Validate SQL';
-$strNone = '';
 $strNotNumber = '   !';
 $strNotOK = '  OK';
 $strNotSet = '  <b>%s</b>         %s';
-$strNotValidNumber = '      !';
+$strNoUsersFound = ' ().';
+$strNoValidateSQL = ' Validate SQL';
 $strNull = '';
 $strNumSearchResultsInTable = '%s ()   <i>%s</i>';
 $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ()';
 $strNumTables = '';
 
-$strOK = 'OK';
 $strOftenQuotation = ' .  ,    char  varchar    .';
+$strOK = 'OK';
 $strOperations = '';
 $strOperator = '';
 $strOptimizeTable = '  ';
@@ -431,15 +439,13 @@ $strOr = '';
 $strOverhead = ' ';
 $strOverwriteExisting = '   ';
 
-$strPHP40203 = '  PHP 4.2.3,      -  (mbstring).    PHP  19404.         PHP  phpMyAdmin.';
-$strPHPVersion = '  PHP';
 $strPageNumber = '  :';
 $strPaperSize = '  ';
 $strPartialText = ' ';
-$strPassword = '';
 $strPasswordChanged = '  %s   .';
 $strPasswordEmpty = '  !';
 $strPasswordNotSame = '   !';
+$strPassword = '';
 $strPdfDbSchema = '     "%s" -  %s';
 $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
@@ -448,17 +454,19 @@ $strPerMinute = ' ';
 $strPerSecond = ' ';
 $strPersian = '';
 $strPhoneBook = ' ';
+$strPHP40203 = '  PHP 4.2.3,      -  (mbstring).    PHP  19404.         PHP  phpMyAdmin.';
 $strPhp = '  PHP ';
+$strPHPVersion = '  PHP';
 $strPmaDocumentation = 'phpMyAdmin ';
 $strPmaUriError = ' <tt>$cfg[\'PmaAbsoluteUri\']</tt>        !';
 $strPolish = '';
 $strPortrait = '';
 $strPos1 = '';
 $strPrevious = '';
-$strPrimary = 'PRIMARY';
 $strPrimaryKeyHasBeenDropped = '    .';
 $strPrimaryKeyName = '      ... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b></b>     <b>  </b>  !)';
+$strPrimary = 'PRIMARY';
 $strPrint = '';
 $strPrintView = '  ';
 $strPrintViewFull = '   (  )';
@@ -496,9 +504,9 @@ $strPrivilegesReloaded = '   .';
 $strProcesslist = '  ';
 $strPutColNames = '      ';
 
-$strQBE = '  ';
 $strQBEDel = '';
 $strQBEIns = '';
+$strQBE = '  ';
 $strQueryFrame = '  ';
 $strQueryOnDb = 'SQL-     <b>%s</b>:';
 $strQuerySQLHistory = 'SQL-';
@@ -507,66 +515,55 @@ $strQueryTime = '  %01.4f ';
 $strQueryType = '  ';
 $strQueryWindowLock = '      ';
 
-$strReType = '';
 $strReceived = '';
 $strRecords = '';
 $strReferentialIntegrity = '    ';
 $strRefresh = '';
-$strRelationNotWorking = '      (linked)   .      %s%s.';
-$strRelationView = '  ';
 $strRelationalSchema = ' ';
+$strRelationNotWorking = '      (linked)   .      %s%s.';
 $strRelations = '';
 $strRelationsForTable = '  ';
+$strRelationView = '  ';
 $strReloadFailed = '     MySQL.';
-$strReloadMySQL = '  MySQL';
 $strReloadingThePrivileges = '  ';
+$strReloadMySQL = '  MySQL';
 $strRemoveSelectedUsers = '   ';
 $strRenameDatabaseOK = '  %s    %s';
 $strRenameTable = '   ';
 $strRenameTableOK = ' %s    %s';
 $strRepairTable = '  ';
-$strReplace = '';
 $strReplaceNULLBy = ' NULL ';
+$strReplace = '';
 $strReplaceTable = '       ';
 $strReset = '';
 $strResourceLimits = ' ';
-$strRevoke = '';
-$strRevokeAndDelete = '          .';
+$strReType = '';
 $strRevokeAndDeleteDescr = '     USAGE      .';
+$strRevokeAndDelete = '          .';
 $strRevokeMessage = '    %s';
+$strRevoke = '';
 $strRomanian = '';
 $strRowLength = '  ';
-$strRowSize = '    ';
 $strRows = '';
 $strRowsFrom = '  ';
+$strRowSize = '    ';
 $strRowsModeFlippedHorizontal = ' ( )';
 $strRowsModeHorizontal = '';
 $strRowsModeOptions = ' %s          %s<br />';
 $strRowsModeVertical = '';
 $strRowsStatistic = '  ';
+$strRunning = '  %s';
 $strRunQuery = ' ';
 $strRunSQLQuery = ' SQL /     %s';
-$strRunning = '  %s';
 $strRussian = '';
 
-$strSQL = 'SQL';
-$strSQLExportCompatibility = '   SQL';
-$strSQLExportType = '  ';
-$strSQLOptions = '   SQL';
-$strSQLParserBugMessage = '        SQL .   -,     .        ,           .                MySQL.    MySQL  -,   ,         .                  ,    SQL     ,           CUT  -:';
-$strSQLParserUserError = ',     SQL  .    MySQL   ,   ,         ';
-$strSQLQuery = 'SQL ';
-$strSQLResult = 'SQL ';
-$strSQPBugInvalidIdentifer = ' ';
-$strSQPBugUnclosedQuote = ' ';
-$strSQPBugUnknownPunctuation = '   ';
-$strSave = '';
 $strSaveOnServer = '     %s';
+$strSave = '';
 $strScaleFactorSmall = '           ';
-$strSearch = '';
 $strSearchFormTitle = '    ';
 $strSearchInTables = ' :';
 $strSearchNeedle = '     (  : "%"):';
+$strSearch = '';
 $strSearchOption1 = '   ';
 $strSearchOption2 = ' ';
 $strSearchOption3 = ' ';
@@ -581,8 +578,8 @@ $strSelectNumRows = ' ';
 $strSelectTables = ' ';
 $strSend = '';
 $strSent = '';
-$strServer = '';
 $strServerChoice = '  ';
+$strServer = '';
 $strServerNotResponding = '   ';
 $strServerStatus = '    MySQL ';
 $strServerStatusUptime = ' MySQL    %s.    %s.';
@@ -591,33 +588,44 @@ $strServerTabVariables = '';
 $strServerTrafficNotes = '<b>  </b>:         MySQL     .';
 $strServerVars = '   ';
 $strServerVersion = '  ';
-$strSessionValue = '  ';
+$strSessionValue = ' ';
 $strSetEnumVal = '     "enum"  "set",      : \'a\',\'b\',\'c\'...<br />       ("\")   ("\'")   ,      (:  \'\\\\xyz\'  \'a\\\'b\').';
-$strShow = '';
 $strShowAll = ' ';
 $strShowColor = ' ';
 $strShowDatadictAs = '    ';
 $strShowFullQueries = '   ';
 $strShowGrid = ' ';
+$strShowingRecords = '   ';
 $strShowPHPInfo = '  PHP ';
 $strShowTableDimension = '   ';
 $strShowTables = ' ';
 $strShowThisQuery = '    ';
-$strShowingRecords = '   ';
+$strShow = '';
 $strSimplifiedChinese = ' ';
 $strSingly = '()';
 $strSize = '';
 $strSlovak = '';
 $strSlovenian = '';
-$strSort = '';
 $strSortByKey = '  ';
+$strSort = '';
 $strSpaceUsage = ' ';
 $strSpanish = '';
 $strSplitWordsWithSpace = '       (" ").';
+$strSQLExportCompatibility = '   SQL';
+$strSQLExportType = '  ';
+$strSQLOptions = '   SQL';
+$strSQLParserBugMessage = '        SQL .   -,     .        ,           .                MySQL.    MySQL  -,   ,         .                  ,    SQL     ,           CUT  -:';
+$strSQLParserUserError = ',     SQL  .    MySQL   ,   ,         ';
+$strSQLQuery = 'SQL ';
+$strSQLResult = 'SQL ';
+$strSQL = 'SQL';
+$strSQPBugInvalidIdentifer = ' ';
+$strSQPBugUnclosedQuote = ' ';
+$strSQPBugUnknownPunctuation = '   ';
 $strStatCheckTime = ' ';
 $strStatCreateTime = '  ';
-$strStatUpdateTime = ' ';
 $strStatement = '';
+$strStatUpdateTime = ' ';
 $strStatus = '';
 $strStorageEngine = '  ';
 $strStorageEngines = '  ';
@@ -634,7 +642,6 @@ $strSum = '';
 $strSwedish = '';
 $strSwitchToTable = '   ';
 
-$strTable = ' ';
 $strTableComments = '  ';
 $strTableEmpty = '    !';
 $strTableHasBeenDropped = ' %s  ';
@@ -643,16 +650,17 @@ $strTableHasBeenFlushed = '   %s  ';
 $strTableMaintenance = '  ';
 $strTableOfContents = '';
 $strTableOptions = '  ';
+$strTables = '%s ()';
 $strTableStructure = '  ';
 $strTableType = '  ';
-$strTables = '%s ()';
+$strTable = ' ';
 $strTblPrivileges = '   ';
 $strTextAreaLength = '   ,<br />        ';
 $strThai = '';
 $strTheContent = '    .';
 $strTheContents = '              .';
-$strTheTerminator = '    .';
 $strTheme = ' / ';
+$strTheTerminator = '    .';
 $strThisHost = ' ';
 $strThisNotDirectory = '   ';
 $strThreadSuccessfullyKilled = ' %s   .';
@@ -682,18 +690,14 @@ $strUnicode = 'Unicode';
 $strUnique = '';
 $strUnknown = '';
 $strUnselectAll = '  ';
-$strUpdComTab = '           Column_comments ';
 $strUpdatePrivMessage = '    %s.';
 $strUpdateProfileMessage = '  .';
 $strUpdateQuery = ' ';
+$strUpdComTab = '           Column_comments ';
 $strUpgrade = '    %s %s  -.';
 $strUsage = '';
 $strUseBackquotes = '         ';
 $strUseHostTable = '  Host';
-$strUseTables = ' ';
-$strUseTextField = '  ';
-$strUseThisValue = '  ';
-$strUser = '';
 $strUserAlreadyExists = ' %s  !';
 $strUserEmpty = '   !';
 $strUserName = ' ';
@@ -701,17 +705,22 @@ $strUserNotFound = '        .';
 $strUserOverview = '  ';
 $strUsersDeleted = '    .';
 $strUsersHavingAccessToDb = '     &quot;%s&quot;';
+$strUser = '';
+$strUseTables = ' ';
+$strUseTextField = '  ';
+$strUseThisValue = '  ';
 
 $strValidateSQL = ' SQL-';
 $strValidatorError = 'SQL      .       PHP ,      %s%s.';
 $strValue = '';
 $strVar = '';
-$strViewDump = '  ';
-$strViewDumpDB = '  ';
 $strViewDumpDatabases = '      ';
+$strViewDumpDB = '  ';
+$strViewDump = '  ';
+$strViewHasBeenDropped = ' %s  ';
 
-$strWebServerUploadDirectory = '  upload   ';
 $strWebServerUploadDirectoryError = '     upload     ';
+$strWebServerUploadDirectory = '  upload   ';
 $strWelcome = '   %s';
 $strWestEuropean = '-';
 $strWildcard = '  ';
@@ -729,43 +738,45 @@ $strZeroRemovesTheLimit = ':      0 ()  .';
 $strZip = '"zip-"';
 
 // To translate:
-$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strAndThen = 'and then';  //to translate
 
+$strBinaryLog = 'Binary log';  //to translate
 $strBinLogEventType = 'Event type';  //to translate
 $strBinLogInfo = 'Information';  //to translate
 $strBinLogName = 'Log name';  //to translate
 $strBinLogOriginalPosition = 'Original position';  //to translate
 $strBinLogPosition = 'Position';  //to translate
 $strBinLogServerId = 'Server ID';  //to translate
-$strBinaryLog = 'Binary log';  //to translate
-$strBufferPool = 'Buffer Pool';  //to translate
 $strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
 $strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
-$strBufferReadMisses = 'Read misses';  //to translate
 $strBufferReadMissesInPercent = 'Read misses in %';  //to translate
-$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
 $strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
 $strBusyPages = 'Busy pages';  //to translate
 
 $strCheckOverhead = 'Check tables with overhead';  //to translate
-$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 
-$strDBCopy = 'Copy database to';  //to translate
 $strDataPages = 'Pages containing data';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
 $strDirtyPages = 'Dirty pages';  //to translate
 
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
 
 $strFreePages = 'Free pages';  //to translate
 
+$strGenerate = 'Generate';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
 $strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
 $strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 
-$strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
 $strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
@@ -787,13 +798,12 @@ $strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem
 $strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
 $strMyISAMDataPointerSize = 'Data pointer size';  //to translate
 $strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
-$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
 $strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
-$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
 $strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
 $strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
-$strMyISAMRepairThreads = 'Repair threads';  //to translate
 $strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
 $strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
 
 $strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
@@ -801,8 +811,16 @@ $strNoThemeSupport = 'No themes support, please check your configuration and/or
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
 
 $strReadRequests = 'Read requests';  //to translate
+$strRoutines = 'Routines';  //to translate
 
 $strSelectBinaryLog = 'Select binary log to view';  //to translate
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
@@ -811,12 +829,12 @@ $strSwitchToDatabase = 'Switch to copied database';  //to translate
 
 $strTakeIt = 'take it';  //to translate
 $strToggleScratchboard = 'toggle scratchboard';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
 
 $strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
 
 $strVersionInformation = 'Version information';  //to translate
 $strView = 'View';  //to translate
-$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
 
 $strWriteRequests = 'Write requests';  //to translate
 
