@@ -428,7 +428,6 @@ $strNone = 'Nincs';
 $strNotNumber = 'Ez nem egy szm!';
 $strNotOK = 'Nincs rendben';
 $strNotSet = '<b>%s</b> tblt nem talltam vagy nincs benne: %s';
-$strNotValidNumber = ' nem rvnyes sorszm!';
 $strNull = 'Null';
 $strNumSearchResultsInTable = '%s tallat <i>%s</i> tblban';
 $strNumSearchResultsTotal = '<b>sszes:</b> <i>%s</i> tallat';
@@ -826,6 +825,13 @@ $strSocketProblem = '(or the local MySQL server\'s socket is not correctly confi
 $strStorageEngine = 'Storage Engine';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+
 $strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
 
+$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
+$strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
+$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
+$strAndThen = 'and then';  //to translate
 ?>
