@@ -1,5 +1,5 @@
 <?php
-/* $Id: japanese-sjis.inc.php,v 2.74.2.1 2005/06/30 18:53:58 lem9 Exp $ */
+/* $Id: japanese-sjis.inc.php,v 2.80 2005/08/19 17:01:49 lem9 Exp $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
@@ -18,7 +18,7 @@ $byteUnits = array('oCg', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 
 $day_of_week = array('', '', '', '', '', '', 'y');
 $month = array('1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 ');
-// See http://www.php.net/manual/en/function.strftime.php to define the
+// See http://www.php.net/manual/ja/function.strftime.php to define the
 // variable below
 $datefmt = '%Y N %B %d  %H:%M';
 $timespanfmt = '%s  %s  %s  %s b';
@@ -475,7 +475,6 @@ $strNone = '';
 $strNotNumber = '͐lł͂܂B';
 $strNotOK = 'OK ł͂܂B';
 $strNotSet = '<b>%s</b> e[uȂA%s ܂B';
-$strNotValidNumber = ' ͍s̐ԍł͂܂ ';
 $strNull = '̒l(NULL)';
 $strNumSearchResultsInTable = '%s  <i>%s</i> e[uŌ܂B';
 $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ܂B';
@@ -823,7 +822,14 @@ $strLatchedPages = 'Latched pages';  //to translate
 
 $strMIME_nodescription = '̕ϊɂ͗LȐ܂B<br />Please ask the author, what %s does.';//to translate
 $strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
-$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAMe[uɎgp MAX_ROWS IvVw肳Ȃꍇ̃oCgw̃ftHg|C^[TCYłB';  //to translate
+$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAMe[uɎgp MAX_ROWS IvVw肳Ȃꍇ̃oCgw̃ftHg|C^[TCYłB';
 $strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
 
+$strTransformation_application_octetstream__hex = 'f[^ 16 i\łB';
+
+$strInvalidFieldCount = 'e[u͏ȂƂЂƂ̃tB[hKvłB';
+$strInvalidRowNumber = '%d ͐ȂsԍłB';
+$strInvalidColumnCount = 'J 0 傫Ȃ΂܂B';
+$strInvalidFieldAddCount = 'ȂƂЂƂ̃tB[hǉȂ΂Ȃ܂B';
+$strAndThen = 'and then';  //to translate
 ?>
